pub struct Node { /* private fields */ }Expand description
All the functionality is implemented in the Node structure. To interact with the other
services of the Sabaton system, a node structure must be created.
The NodeBuilder structure provides a builder pattern to create
the node. A node is cloneable.
Implementations
Sourceimpl Node
impl Node
pub fn advertise_with_listener<T: TopicType>( &self, options: &PublishOptions, listener: PublisherListener, ) -> Result<Writer<T>, MiddlewareError>
Sourcepub fn advertise<T>(
&self,
options: &PublishOptions,
) -> Result<Writer<T>, MiddlewareError>where
T: TopicType,
pub fn advertise<T>(
&self,
options: &PublishOptions,
) -> Result<Writer<T>, MiddlewareError>where
T: TopicType,
Advertise a Type to the rest of the system. This call returns a Writer
pub fn subscribe_with_listener<T>(
&self,
options: &SubscribeOptions,
listener: SubscriberListener,
) -> Result<Reader<T>, MiddlewareError>where
T: TopicType,
Sourcepub fn subscribe<T>(
&self,
options: &SubscribeOptions,
) -> Result<Reader<T>, MiddlewareError>where
T: TopicType,
pub fn subscribe<T>(
&self,
options: &SubscribeOptions,
) -> Result<Reader<T>, MiddlewareError>where
T: TopicType,
Subscribe to a topic. This call returns a Reader
Sourcepub fn subscribe_async<T>(
&self,
options: &SubscribeOptions,
) -> Result<Reader<T>, MiddlewareError>where
T: TopicType,
pub fn subscribe_async<T>(
&self,
options: &SubscribeOptions,
) -> Result<Reader<T>, MiddlewareError>where
T: TopicType,
Subscribe to a topic. This call returns a Reader
Sourcepub fn create_proxy<T: 'static + Proxy + ProxyConstruct + ServiceIdentifier + ServiceVersion + Clone>(
&self,
) -> Result<T, MiddlewareError>
pub fn create_proxy<T: 'static + Proxy + ProxyConstruct + ServiceIdentifier + ServiceVersion + Clone>( &self, ) -> Result<T, MiddlewareError>
create a proxy for a service
Sourcepub fn serve<T: CreateServerRequestHandler<Item = T>>(
&self,
server_impl: Arc<T>,
) -> Result<(), MiddlewareError>
pub fn serve<T: CreateServerRequestHandler<Item = T>>( &self, server_impl: Arc<T>, ) -> Result<(), MiddlewareError>
Hosting a service
Sourcepub fn spin<F>(&self, main_function: F) -> Result<(), MiddlewareError>
pub fn spin<F>(&self, main_function: F) -> Result<(), MiddlewareError>
The main processing loop of the node. This function will block waiting for events and pumping the necessary callbacks.